<?php

namespace Litecms\BoardSetting\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\BoardSetting\Models\BoardSetting;

class BoardSettingPolicy
{

    /**
     * Determine if the given user can view the board_setting.
     *
     * @param UserPolicy $user
     * @param BoardSetting $board_setting
     *
     * @return bool
     */
    public function view(UserPolicy $user, BoardSetting $board_setting)
    {
        if ($user->canDo('board_setting.board_setting.view') && $user->isAdmin()) {
            return true;
        }

        return $board_setting->user_id == user_id() && $board_setting->user_type == user_type();
    }

    /**
     * Determine if the given user can create a board_setting.
     *
     * @param UserPolicy $user
     * @param BoardSetting $board_setting
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('board_setting.board_setting.create');
    }

    /**
     * Determine if the given user can update the given board_setting.
     *
     * @param UserPolicy $user
     * @param BoardSetting $board_setting
     *
     * @return bool
     */
    public function update(UserPolicy $user, BoardSetting $board_setting)
    {
        if ($user->canDo('board_setting.board_setting.edit') && $user->isAdmin()) {
            return true;
        }

        return $board_setting->user_id == user_id() && $board_setting->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given board_setting.
     *
     * @param UserPolicy $user
     * @param BoardSetting $board_setting
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, BoardSetting $board_setting)
    {
        return $board_setting->user_id == user_id() && $board_setting->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given board_setting.
     *
     * @param UserPolicy $user
     * @param BoardSetting $board_setting
     *
     * @return bool
     */
    public function verify(UserPolicy $user, BoardSetting $board_setting)
    {
        if ($user->canDo('board_setting.board_setting.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given board_setting.
     *
     * @param UserPolicy $user
     * @param BoardSetting $board_setting
     *
     * @return bool
     */
    public function approve(UserPolicy $user, BoardSetting $board_setting)
    {
        if ($user->canDo('board_setting.board_setting.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
